if command -v gettext > /dev/null; then
    _gettext() { gettext -- "$@"; }
else
    _gettext() { printf -- "%s" "$@"; }
fi

get_arch() {
	ARCH=$(jq -r .arch "${PROJECT_HOME:-.}/info.json")
	[ -n "$ARCH" ] \
		|| error $"Could not read arch from info.json" \
			$"info.json should have been created at project creation, please recreate" \
			$"the project from ABOSDE and contact support if this does not help."
}

get_carch() {
	[ -n "$ARCH" ] || get_arch
	case "$ARCH" in
	arm64|aarch64) CARCH="arm64v8";;
	armv7) CARCH="arm32v7";;
	armhf) CARCH="arm32v6";;
	x86_64) CARCH="amd64";;
	*) error $"Got invalid arch: $ARCH";;
	esac
}

prompt() {
    local var="$1"
    local prompt_fmt="$2"
    shift 2
    # shellcheck disable=SC2059 # fmt is a build time constant
    printf -- "$(_gettext "$prompt_fmt") " "$@"
    read -r "${var?}"
}

prompt_yesno() {
    local default="$1"
    shift 1
    local yesno

    while true; do
        prompt yesno "$@"
        [ -n "$yesno" ] || yesno="$default"
        case "$yesno" in
        [Yy]|[Yy][Ee][Ss]|[Tt][Rr][Uu][Ee]|1)
            return 0;;
        [Nn]|[Nn][Oo]|[Ff][Aa][Ll][Ss][Ee]|0)
            return 1;;
        esac
    done
}
